@@ -39,14 +39,14 @@ class ToolsLoader:
     
     # 静态定义所有工具模块映射
     TOOL_MODULES = {
-        'ansible_tools_plus': (ansible_tools_plus, True),
-        'current_time_tools': (current_time_tools, False),
-        'duckduckgo_tools': (duckduckgo_tools, False),
-        'github_tools': (github_tools, False),
-        'http_request_tools_plus': (http_request_tools_plus, True),
-        'jenkins_tools': (jenkins_tools, False),
-        'kubernetes_tools': (kubernetes_tools, False),
-        'python_tools': (python_tools, False),
+        'ansible': (ansible_tools_plus, True),
+        'current_time': (current_time_tools, False),
+        'duckduckgo': (duckduckgo_tools, False),
+        'github': (github_tools, False),
+        'http_request': (http_request_tools_plus, True),
+        'jenkins': (jenkins_tools, False),
+        'kubernetes': (kubernetes_tools, False),
+        'python': (python_tools, False),
     }
 
     @staticmethod
@@ -129,7 +129,6 @@ class ToolsLoader:
             if processed_tool:
                 tools.append(processed_tool)
 
-        logger.info(f"成功加载 {len(tools)} 个 '{tools_name}' 类别的工具")
         return tools
 
     @staticmethod
